@@ -4,14 +4,14 @@ use warnings;
 
 package Git::Wrapper;
 #ABSTRACT: Wrap git(7) command-line interface
-$Git::Wrapper::VERSION = '0.044_92'; # TRIAL
+$Git::Wrapper::VERSION = '0.039'; # TRIAL
 our $DEBUG=0;
 
 # Prevent ANSI color with extreme prejudice
 # https://github.com/genehack/Git-Wrapper/issues/13
 delete $ENV{GIT_PAGER_IN_USE};
 
-use File::chdir;
+use File::pushd;
 use File::Temp;
 use IPC::Open3      qw();
 use Scalar::Util    qw(blessed);
@@ -83,7 +83,7 @@ sub RUN {
   my( @out , @err );
 
   {
-    local $CWD = $self->dir unless $cmd eq 'clone';
+    my $d = pushd $self->dir unless $cmd eq 'clone';
 
     my ($wtr, $rdr, $err);
 
@@ -168,18 +168,9 @@ sub has_git_in_path {
 sub log {
   my $self = shift;
 
-  if ( grep /format=/, @_ ) {
-    die Git::Wrapper::Exception->new(
-      error  => [qw/--format not allowed. Use the RUN() method if you with to use a custom log format./],
-      output => undef,
-      status => 255 ,
-    );
-  }
-
   my $opt  = ref $_[0] eq 'HASH' ? shift : {};
   $opt->{no_color}         = 1;
   $opt->{pretty}           = 'medium';
-  $opt->{no_abbrev}        = 1;  # https://github.com/genehack/Git-Wrapper/issues/67
 
   $opt->{no_abbrev_commit} = 1
     if $self->supports_log_no_abbrev_commit;
@@ -220,9 +211,7 @@ sub log {
     if ($raw) {
       my @modifications;
 
-      # example output:
-      # :000000 100644 0000000000000000000000000000000000000000 ce013625030ba8dba906f756967f9e9ca394464a A     foo/bar
-      while(@out and $out[0] =~ m/^\:(\d{6}) (\d{6}) (\w{40}) (\w{40}) (\w{1})\t(.*)$/) {
+      while(@out and $out[0] =~ m/^\:(\d{6}) (\d{6}) (\w{7})\.\.\. (\w{7})\.\.\. (\w{1})\t(.*)$/) {
         push @modifications, Git::Wrapper::File::RawModification->new($6,$5,$1,$2,$3,$4);
         shift @out;
       }
@@ -230,9 +219,6 @@ sub log {
     }
 
     push @logs, $current;
-
-    last unless @out; # handle running out of log
-    shift @out unless $out[0] =~ /^commit/;  # blank line at end of entry, except merge commits;
   }
 
   return @logs;
@@ -402,7 +388,7 @@ Git::Wrapper - Wrap git(7) command-line interface
 
 =head1 VERSION
 
-version 0.044_92
+version 0.039
 
 =head1 SYNOPSIS
 
@@ -548,9 +534,7 @@ L<Git::Wrapper>.
 
 =head3 Using C<eval>
 
-If for some reason you are unable to use L<Try::Tiny>, it is also possible to
-use the C<eval> function to catch exception objects. B<THIS IS NOT
-RECOMMENDED!>
+If for some reason you are unable to use L<Try::Tiny>, it is also possible to use the C<eval> function to catch exception objects. B<THIS IS NOT RECOMMENDED!>
 
   my $git = Git::Wrapper->new('/path/to/my/repo');
 
@@ -609,9 +593,7 @@ you want ANSI color highlighting, you'll need to bypass via the RUN() method
   my @logs = $git->log;
 
 Instead of giving back an arrayref of lines, the C<log> method returns a list
-of C<Git::Wrapper::Log> objects.
-
-There are five methods in a C<Git::Wrapper::Log> objects:
+of C<Git::Wrapper::Log> objects. They have four methods:
 
 =over
 
@@ -623,46 +605,8 @@ There are five methods in a C<Git::Wrapper::Log> objects:
 
 =item * message
 
-=item * modifications
-
-Only populated with when C<< raw => 1 >> option is set; see L<Raw logs> below.
-
 =back
 
-=head3 Raw logs
-
-Calling the C<log> method with the C<< raw => 1 >> option set, as below, will
-do additional parsing to populate the C<modifications> attribute on each
-C<Git::Wrapper::Log> object. This method returns a list of
-C<Git::Wrapper::File::RawModification> objects, with can be used to get
-filenames, permissions, and other metadata associated with individual files in
-the given commit. A short example, to loop over all commits in the log and
-print the filenames that were changed in each commit, one filename per file:
-
-    my @logs = $git->log({ raw => 1 });
-    foreach my $log ( @logs ) {
-        say "In commit '" . $log->id . "', the following files changed:";
-        my @mods = $log->modifications;
-        foreach my $mod ( @mods ) {
-            say "\t" . $mod->filename;
-        }
-    }
-
-Note that some commits (e.g., merge commits) will not contain any file
-changes. The C<modifications> method will return an empty list in that case.
-
-=head3 Custom log formats
-
-C<log> will throw an exception if it is passed the C<--format> option. The
-reason for this has to do with the fact that the parsing of the full log
-output into C<Git::Wrapper::Log> objects assumes the default format provided
-by `git` itself. Passing C<--format> to the underlying `git log` method affects
-this assumption and the output is no longer able to be processed as intented.
-
-If you wish to specify a custom log format, please use the L<RUN> method
-directly.  The caller will be supplied with the full log output. From there,
-the caller may process the output as it wishes.
-
 =head2 has_git_in_path
 
 This method returns a true or false value indicating if there is a 'git'
@@ -829,9 +773,6 @@ values, and then a list of any other arguments.
     # while 'RUN('log')' returns an array of chomped lines
     my @log_lines = $git->RUN('log');
 
-    # getting the full of commit SHAs via `git log` by using the '--format' option
-    my @log_lines = $git->RUN('log', '--format=%H');
-
 =head2 ERR
 
 After a command has been run, this method will return anything that was sent
